@@ -16,7 +16,7 @@
 # @synopsis
 #
 # \arguments{
-#   \item{CT}{A @numeric @vector of J tumor total tumor copy number (TCN)
+#   \item{CT}{A @numeric @vector of J tumor total copy number (TCN)
 #        ratios in [0,+@Inf) (due to noise, small negative values are
 #        also allowed).  The TCN ratios are typically scaled such that
 #        copy-neutral diploid loci have a mean of two.}
@@ -60,7 +60,7 @@
 #   } 
 #   \item{knownSegments}{Optional @data.frame specifying 
 #     \emph{non-overlapping} known segments.  These segments must
-#     not share loci.}
+#     not share loci.  See @see "findLargeGaps" and @see "gapsToSegments".}
 #   \item{seed}{An (optional) @integer specifying the random seed to be 
 #     set before calling the segmentation method.  The random seed is
 #     set to its original state when exiting.  If @NULL, it is not set.}
@@ -422,7 +422,7 @@ setMethodS3("segmentByPairedPSCBS", "default", function(CT, betaT, betaN=NULL, m
       verbose && exit(verbose);
     } # for (kk ...)
 
-    verbose && enter(verbose, "Merging (independently segmented chromosome)");
+    verbose && enter(verbose, "Merging (independently) segmented chromosome");
     fit <- Reduce(append, fitList);
     # Not needed anymore
     rm(fitList);
